@@ -119,8 +119,7 @@ class RenderJob(VisualJob):
         except JobAbortedException:
             pass
         with self.resultsForRendererLock:
-            while self.resultsForRendererCache.has_key(
-                                        self.resultForRendererIdx):
+            while self.resultForRendererIdx in self.resultsForRendererCache:
                 idx = self.resultForRendererIdx
 
                 self.__logger.debug("%s: %s: resultToFetch: %s",
@@ -175,7 +174,7 @@ class RendererResultTask(WorkLoad):
         return self.task.GetInfo()
 
 
-class TaskResultCacheEntry(object):
+class TaskResultCacheEntry:
 
     NO_RESULT = object()
 
