@@ -43,8 +43,8 @@ class PhotoFilmStripList(wx.ScrolledWindow):
     THUMB_HEIGHT = 120
     HOLE_WIDTH = 11
     HOLE_HEIGHT = 16
-    HOLE_PADDING = 13       # distance between holes
-    HOLE_MARGIN = 6         # distance to thumb
+    HOLE_PADDING = 13  # distance between holes
+    HOLE_MARGIN = 6  # distance to thumb
     LABEL_MARGIN = 8
 
     STRIP_HEIGHT = THUMB_HEIGHT + 2 * BORDER
@@ -56,17 +56,17 @@ class PhotoFilmStripList(wx.ScrolledWindow):
         self.SetBackgroundStyle(wx.BG_STYLE_CUSTOM)
         self.SetBackgroundColour(wx.BLACK)
         clientSize = wx.Size(-1, self.STRIP_HEIGHT + wx.SystemSettings.GetMetric(wx.SYS_HSCROLL_Y))
-        self.SetSizeHintsSz(clientSize, clientSize)
+        self.SetSizeHints(clientSize, clientSize)
 
         self.__frozen = False
         self.__pictures = []
         self.__selIdxs = []
         self.__hvrIdx = -1
 
-        self.__dragIdx = None
-        self.__dropIdx = None
+        self.__dragIdx = -1
+        self.__dropIdx = -1
         self.__dragBmp = None
-        self.__dragBmpIdx = None
+        self.__dragBmpIdx = -1
         self.__dragX = 0
         self.__dragOffX = 0
 
@@ -102,7 +102,7 @@ class PhotoFilmStripList(wx.ScrolledWindow):
         pdc = wx.BufferedPaintDC(self)
         try:
             dc = wx.GCDC(pdc)
-        except StandardError:
+        except Exception:
             dc = pdc
 
         dc.SetBackground(wx.BLACK_BRUSH)
@@ -122,7 +122,7 @@ class PhotoFilmStripList(wx.ScrolledWindow):
             diaRect.SetWidth(bmpWidth + self.GAP)
 
             if idx == self.__dropIdx and self.__dragIdx > idx:
-                diaRect.OffsetXY(self.__dragBmp.GetWidth(), 0)
+                diaRect.Offset(self.__dragBmp.GetWidth(), 0)
 
             if diaRect.right + 1 >= 0 and idx != self.__dragIdx:
                 if diaRect.left <= clientWidth:
@@ -140,12 +140,12 @@ class PhotoFilmStripList(wx.ScrolledWindow):
                     break
 
             if idx != self.__dragIdx or self.__dragIdx == self.__dropIdx:
-                diaRect.OffsetXY(diaRect.width, 0)
+                diaRect.Offset(diaRect.width, 0)
 
             if idx == self.__dropIdx and self.__dragIdx < idx:
-                diaRect.OffsetXY(self.__dragBmp.GetWidth(), 0)
+                diaRect.Offset(self.__dragBmp.GetWidth(), 0)
 
-        if self.__dragIdx is not None:
+        if self.__dragIdx != -1:
             dc.DrawBitmap(self.__dragBmp, self.__dragX - self.__dragOffX - vx, 0, True)
 
     def __CreateDiaBmp(self, picIdx, selected=False, highlighted=False, dropIdx=None):
@@ -154,14 +154,14 @@ class PhotoFilmStripList(wx.ScrolledWindow):
         diaRect = self.GetDiaRect(picIdx)
         holeOffset = diaRect.x
 
-        bmp = wx.EmptyBitmap(diaRect.width, diaRect.height)
+        bmp = wx.Bitmap(diaRect.width, diaRect.height)
         diaNo = str(picIdx + 1)
         label = os.path.splitext(os.path.basename(pic.GetFilename()))[0]
 
         dc = wx.MemoryDC(bmp)
         try:
             dc = wx.GCDC(dc)
-        except StandardError:
+        except Exception:
             pass
 
         if dropIdx is not None:
@@ -182,12 +182,12 @@ class PhotoFilmStripList(wx.ScrolledWindow):
 
         colour = wx.Colour(235, 235, 235)
 
-        bmpX = rect.x + self.GAP / 2
-        bmpY = (rect.height - thumbBmp.GetHeight()) / 2
+        bmpX = rect.x + self.GAP // 2
+        bmpY = (rect.height - thumbBmp.GetHeight()) // 2
 
-        holeX = rect.x + self.GAP / 2 - (holeOffset % (self.HOLE_WIDTH + self.HOLE_PADDING))
+        holeX = rect.x + self.GAP // 2 - (holeOffset % (self.HOLE_WIDTH + self.HOLE_PADDING))
 
-        dc.SetClippingRect(rect)
+        dc.SetClippingRegion(rect.GetX(), rect.GetY(), rect.GetWidth(), rect.GetHeight())
 
         if selected:
             dc.SetBackground(wx.Brush(wx.Colour(38, 54, 70)))
@@ -208,8 +208,8 @@ class PhotoFilmStripList(wx.ScrolledWindow):
         label, labelWidth = ChopText(dc, label, thumbBmp.GetWidth())
 
         dc.DrawBitmap(thumbBmp, bmpX, bmpY, True)
-        dc.DrawText(diaNo, rect.x + (rect.width - diaNoWidth) / 2, self.LABEL_MARGIN - 3)
-        dc.DrawText(label, rect.x + (rect.width - labelWidth) / 2, rect.height - self.LABEL_MARGIN - textHeight)
+        dc.DrawText(diaNo, rect.x + (rect.width - diaNoWidth) // 2, self.LABEL_MARGIN - 3)
+        dc.DrawText(label, rect.x + (rect.width - labelWidth) // 2, rect.height - self.LABEL_MARGIN - textHeight)
 
         while holeX <= rect.right + 1:
             dc.DrawRoundedRectangle(holeX, self.BORDER - self.HOLE_MARGIN - self.HOLE_HEIGHT, self.HOLE_WIDTH, self.HOLE_HEIGHT, 2)
@@ -219,7 +219,7 @@ class PhotoFilmStripList(wx.ScrolledWindow):
         if highlighted:
             dc.SetPen(wx.TRANSPARENT_PEN)
             dc.SetBrush(wx.Brush(wx.Colour(77, 136, 196, 80)))
-            dc.DrawRectangleRect(rect)
+            dc.DrawRectangle(rect)
 
         dc.DestroyClippingRegion()
 
@@ -259,7 +259,7 @@ class PhotoFilmStripList(wx.ScrolledWindow):
                 self.__Scroll(40)
 
             self.__dragX = unscrolledPos.x
-            if self.__dragIdx is None:
+            if self.__dragIdx == -1:
                 if idx != -1:
                     self.__dragIdx = idx
                     self.__dragBmp = self.__CreateDiaBmp(idx, True, True)
@@ -288,21 +288,21 @@ class PhotoFilmStripList(wx.ScrolledWindow):
                         self.Select(idx)
                     else:
                         step = 1 if idx > self.__selIdxs[0] else -1
-                        for ct, _idx in enumerate(xrange(self.__selIdxs[0],
-                                                         idx + step,
-                                                         step)):
+                        for ct, _idx in enumerate(range(self.__selIdxs[0],
+                                                        idx + step,
+                                                        step)):
                             self.Select(_idx, deselectOthers=ct == 0)
                 else:
                     self.Select(idx)
 
-        if event.LeftUp() and self.__dragIdx is not None:
+        if event.LeftUp() and self.__dragIdx != -1:
             self.__FinishDnD()
 
         event.Skip()
 
     def OnCaptureLost(self, event):
-        self.__dragIdx = None
-        self.__dropIdx = None
+        self.__dragIdx = -1
+        self.__dropIdx = -1
         self.Refresh()
         event.Skip()
 
@@ -341,14 +341,14 @@ class PhotoFilmStripList(wx.ScrolledWindow):
             self.EnsureVisible(0)
 
         elif key == wx.WXK_ESCAPE:
-            if self.__dragIdx is not None:
+            if self.__dragIdx != -1:
                 self.__FinishDnD(abort=True)
 
         else:
             event.Skip()
 
     def __FinishDnD(self, abort=False):
-        if self.__dragIdx is not None:
+        if self.__dragIdx != -1:
             if self.HasCapture():
                 self.ReleaseMouse()
 
@@ -358,8 +358,8 @@ class PhotoFilmStripList(wx.ScrolledWindow):
                 self.Select(self.__dropIdx)
                 idx = self.__dropIdx
 
-            self.__dragIdx = None
-            self.__dropIdx = None
+            self.__dragIdx = -1
+            self.__dropIdx = -1
 
             self.Refresh()
             self.EnsureVisible(idx)
@@ -385,7 +385,7 @@ class PhotoFilmStripList(wx.ScrolledWindow):
         self.Refresh()
 
     def GetThumbSize(self, pic):
-        aspect = float(pic.GetWidth()) / float(pic.GetHeight())
+        aspect = pic.GetWidth() / pic.GetHeight()
         thumbHeight = self.THUMB_HEIGHT
         thumbWidth = int(round(thumbHeight * aspect))
         return thumbWidth, thumbHeight
@@ -422,7 +422,7 @@ class PhotoFilmStripList(wx.ScrolledWindow):
     def InsertPicture(self, idx, pic):
         self.__pictures.insert(idx, pic)
 
-        for i in xrange(len(self.__selIdxs)):
+        for i in range(len(self.__selIdxs)):
             if self.__selIdxs[i] >= idx \
             and self.__selIdxs[i] + 1 not in self.__selIdxs:
                 self.__selIdxs[i] += 1
@@ -450,7 +450,7 @@ class PhotoFilmStripList(wx.ScrolledWindow):
         if len(self.__selIdxs) == 0:
             self.__selIdxs.append(firstSel)
 
-        for i in xrange(len(self.__selIdxs)):
+        for i in range(len(self.__selIdxs)):
             if self.__selIdxs[i] > idx \
             and self.__selIdxs[i] - 1 not in self.__selIdxs:
                 self.__selIdxs[i] -= 1
@@ -483,7 +483,7 @@ class PhotoFilmStripList(wx.ScrolledWindow):
             return None
 
     def SetPicture(self, idx, pic):
-        if idx in xrange(len(self.__pictures)):
+        if idx in range(len(self.__pictures)):
             self.__pictures[idx] = pic
             self.Refresh()
 
@@ -502,7 +502,7 @@ class PhotoFilmStripList(wx.ScrolledWindow):
         return selPics
 
     def Select(self, idx, on=True, deselectOthers=True):
-        if idx in xrange(len(self.__pictures)):
+        if idx in range(len(self.__pictures)):
             if deselectOthers:
                 newSel = []
             else:
